# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::AL;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
our $VERSION = 1.20141125232348;

my $formatters = [{'leading_digits' => '4[0-6]','pattern' => '(4)(\\d{3})(\\d{4})'},{'leading_digits' => '6','pattern' => '(6[6-9])(\\d{3})(\\d{4})'},{'pattern' => '(\\d{2})(\\d{3})(\\d{3})','leading_digits' => '[2358][2-5]|4[7-9]'},{'pattern' => '(\\d{3})(\\d{3,5})','leading_digits' => '[235][16-9]|8[016-9]|[79]'}];
my $validators = {'geographic' => '(?:2(?:[168][1-9]|[247]\\d|9[1-7])|3(?:1[1-3]|[2-6]\\d|[79][1-8]|8[1-9])|4\\d{2}|5(?:1[1-4]|[2-578]\\d|6[1-5]|9[1-7])|8(?:[19][1-5]|[2-6]\\d|[78][1-7]))\\d{5}','pager' => '','toll_free' => '800\\d{4}','voip' => '','mobile' => '6[6-9]\\d{7}','personal_number' => '700\\d{5}','special_rate' => '(808\\d{3})|(900\\d{3})|()','fixed_line' => '(?:2(?:[168][1-9]|[247]\\d|9[1-7])|3(?:1[1-3]|[2-6]\\d|[79][1-8]|8[1-9])|4\\d{2}|5(?:1[1-4]|[2-578]\\d|6[1-5]|9[1-7])|8(?:[19][1-5]|[2-6]\\d|[78][1-7]))\\d{5}'};sub areaname { my $self = shift; my $number = $self->{number}; my %map = (355211 => "Koplik",355212 => "Puk\Ã\«",355213 => "Bajram\ Curri",355214 => "Krum\Ã\«",355215 => "Lezh\Ã\«",355216 => "Rr\Ã\«shen",355217 => "Burrel",355218 => "Peshkopi",355219 => "Bulqiz\Ã\«",35522 => "Shkod\Ã\«r",35524 => "Kuk\Ã\«s",355261 => "Vau\-Dej\Ã\«s",355262 => "Rrethinat\/Ana\-Malit\,\ Shkod\Ã\«r",355263 => "Pult\/Shal\Ã\«\/Shosh\/Temal\/Shllak\,\ Shkod\Ã\«r",355264 => "Postrib\Ã\«\/Gur\ i\ Zi",355265 => "Vig\-Mnel\Ã\«\/Hajmel\,\ Shkod\Ã\«r",355266 => "Bushat\/B\Ã\«rdic\Ã\«\,\ Shkod\Ã\«r",355267 => "Daj\Ã\§\/Velipoj\Ã\«\,\ Shkod\Ã\«r",355268 => "Qend\Ã\«r\/Gruemir\Ã\«\,\ Mal\Ã\«si\ e\ Madhe",355269 => "Kastrat\/Shkrel\/Kelmend\,\ Mal\Ã\«si\ e\ Madhe",355270 => "Kolsh\/Surroj\/Arren\/Malzi\,\ Kuk\Ã\«s",355271 => "Fush\Ã\«\-Arr\Ã\«z\/Rrap\Ã\«\,\ Puk\Ã\«",355272 => "Qerret\/Qel\Ã\«z\/Gjegjan\,\ Puk\Ã\«",355273 => "Iball\Ã\«\/Fierz\Ã\«\/Blerim\/Qaf\Ã\«\-Mali\,\ Puk\Ã\«",355274 => "Tropoj\Ã\«\/Llugaj\/Margegaj\,\ Tropoj\Ã\«",355275 => "Bujan\/Fierz\Ã\«\/Bytyc\/Lekbiba\,\ Tropoj\Ã\«",355276 => "Fajza\/Golaj\/Gjinaj\,\ Has",355277 => "Shtiqen\/T\Ã\«rthore\/Zapod\,\ Kuk\Ã\«s",355278 => "Bicaj\/Topojan\/Shishtavec\,\ Kuk\Ã\«s",355279 => "Gryk\-\Ã\‡aj\Ã\«\/Ujmisht\/Bushtrice\/Kalis\,\ Kuk\Ã\«s",355281 => "Sh\Ã\«ngjin\/Balldre\,\ Lezh\Ã\«",355282 => "Kallmet\/Blinisht\/Daj\Ã\§\/Ungrej\,\ Lezh\Ã\«",355283 => "Kolsh\/Zejmen\/Sh\Ã\«nkoll\,\ Lezh\Ã\«",355284 => "Rubik\,\ Mirdit\Ã\«",355285 => "Kthjell\Ã\«\/Selit\Ã\«\,\ Mirdit\Ã\«",355286 => "Ka\Ã\§inar\/Orosh\/Fan\,\ Mirdit\Ã\«",355287 => "Klos\/Su\Ã\§\/Lis\,\ Mat",355288 => "Baz\/Komsi\/Gurr\Ã\«\/Xib\Ã\«r\,\ Mat",355289 => "Ul\Ã\«z\/Rukaj\/Derjan\/Macukull\,\ Mat",355291 => "Tomin\/Luzni\,\ Dib\Ã\«r",355292 => "Maqellar\Ã\«\/Melan\,\ Dib\Ã\«r",355293 => "Kastriot\/Muhur\/Selisht\Ã\«\,\ Dib\Ã\«r",355294 => "Arras\/Fush\Ã\«\-\Ã\‡idh\Ã\«n\/Lur\Ã\«\,\ Dib\Ã\«r",355295 => "Sllov\Ã\«\/Zall\-Dardh\Ã\«\/Zall\-Re\Ã\§\/Kala\ e\ Dodes\,\ Dib\Ã\«r",355296 => "Fush\Ã\«\-Bulqiz\Ã\«\/Shupenz\Ã\«\/Zerqan\,\ Bulqiz\Ã\«",355297 => "Gjorice\/Ostren\/Trebisht\/Martanesh\,\ Bulqiz\Ã\«",355311 => "Ku\Ã\§ov\Ã\«",355312 => "\Ã\‡orovod\Ã\«\,\ Skrapar",355313 => "Ballsh\,\ Mallakast\Ã\«r",35532 => "Berat",35533 => "Vlor\Ã\«",35534 => "Fier",35535 => "Lushnje",355360 => "Leshnje\/Potom\/\Ã\‡epan\/Gjerb\Ã\«s\/Zhep\Ã\«\,\ Skrapar",355361 => "Ura\ Vajgurore\,\ Berat",355362 => "Velabisht\/Roshnik\,\ Berat",355363 => "Otllak\/Lumas\,\ Berat",355364 => "V\Ã\«rtop\/Terpan\,\ Berat",355365 => "Sinj\Ã\«\/Cukalat\,\ Berat",355366 => "Poshnj\Ã\«\/Kutalli\,\ Berat",355367 => "Perondi\/Kozar\Ã\«\,\ Ku\Ã\§ov\Ã\«",355368 => "Poli\Ã\§an\/Bogov\Ã\«\,\ Skrapar",355369 => "Qend\Ã\«r\/Vendresh\Ã\«\,\ Skrapar",355371 => "Divjak\Ã\«\,\ Lushnj\Ã\«",355372 => "Karbunar\Ã\«\/Fier\-Shegan\/Hysgjokaj\/Ballagat\,\ Lushnj\Ã\«",355373 => "Krutje\/Bubullim\Ã\«\/Allkaj\,\ Lushnj\Ã\«",355374 => "Gradisht\Ã\«\/Kolonj\Ã\«\,\ Lushnj\Ã\«",355375 => "Golem\/Grabian\/Remas\,\ Lushnj\Ã\«",355376 => "Dushk\/T\Ã\«rbuf\,\ Lushnj\Ã\«",355377 => "Qend\Ã\«r\/Greshic\Ã\«\/Hekal\,\ Mallakast\Ã\«r",355378 => "Aranitas\/Ngracan\/Selit\Ã\«\/Fratar\/Kut\Ã\«\,\ Mallakast\Ã\«r",355381 => "Patos\,\ Fier",355382 => "Roskovec\,\ Fier",355383 => "Qend\Ã\«r\,\ Fier",355384 => "Mbrostar\ Ura\/LIibofsh\Ã\«\,\ Fier",355385 => "Port\Ã\«z\/Zhar\Ã\«z\,\ Fier",355386 => "Kuman\/Kurjan\/Strum\/Ruzhdie\,\ Fier",355387 => "Cakran\/Frakull\,\ Fier",355388 => "Levan\,\ Fier",355389 => "Dermenas\/Topoj\Ã\«\,\ Fier",355391 => "Orikum\,\ Vlor\Ã\«",355392 => "Selenic\Ã\«\,\ Vlor\Ã\«",355393 => "Himar\Ã\«\,\ Vlor\Ã\«",355394 => "Qend\Ã\«r\,\ Vlor\Ã\«",355395 => "Novosel\Ã\«\,\ Vlor\Ã\«",355396 => "Shushic\Ã\«\/Armen\,\ Vlor\Ã\«",355397 => "Vllahin\Ã\«\/Kote\,\ Vlor\Ã\«",355398 => "Sevaster\/Brataj\/Hore\-Vranisht\,\ Vlor\Ã\«",3554 => "Tirana",35547 => "Kam\Ã\«z\/Vor\Ã\«\/Paskuqan\/Zall\-Herr\/Burxull\Ã\«\/Prez\Ã\«\,\ Tiran\Ã\«",35548 => "Kashar\/Vaqar\/Ndroq\/Pez\Ã\«\/Fark\Ã\«\/Dajt\,\ Tiran\Ã\«",35549 => "Petrel\Ã\«\/Baldushk\/B\Ã\«rzhit\Ã\«\/Krrab\Ã\«\/Shengjergj\/Zall\-Bastar\,\ Tiran\Ã\«",355511 => "Kruje",355512 => "Peqin",355513 => "Gramsh",355514 => "Librazhd",35552 => "Durr\Ã\«s",35553 => "La\Ã\§\,\ Kurbin",35554 => "Elbasan",35555 => "Kavaj\Ã\«",355561 => "Mamurras\,\ Kurbin",355562 => "Milot\/Fushe\-Kuqe\,\ Kurbin",355563 => "Fush\Ã\«\-Kruj\Ã\«",355564 => "Nik\Ã\«l\/Bubq\,\ Kruje",355565 => "Koder\-Thumane\/Cudhi\,\ Kruje",355570 => "Gos\Ã\«\/Lekaj\/Sinaballaj\,\ Kavaj\Ã\«",355571 => "Shijak\,\ Durr\Ã\«s",355572 => "Man\Ã\«z\,\ Durr\Ã\«s",355573 => "Sukth\,\ Durr\Ã\«s",355574 => "Rashbull\/Gjepalaj\,\ Durr\Ã\«s",355575 => "Xhafzotaj\/Maminas\,\ Durr\Ã\«s",355576 => "Katund\ i\ Ri\/Ishem\,\ Durr\Ã\«s",355577 => "Rrogozhin\Ã\«\,\ Kavaj\Ã\«",355578 => "Synej\/Golem\,\ Kavaj\Ã\«",355579 => "Luz\ i\ Vog\Ã\«l\/Kryevidh\/Helm\Ã\«s\,\ Kavaj\Ã\«",355580 => "P\Ã\«rparim\/Pajov\Ã\«\,\ Peqin",355581 => "C\Ã\«rrik\,\ Elbasan",355582 => "Belsh\,\ Elbasan",355583 => "Bradashesh\/Shirgjan\,\ Elbasan",355584 => "Labinot\-Fush\Ã\«\/Labinot\-Mal\/Funar\Ã\«\/Gracen\,\ Elbasan",355585 => "Shushic\Ã\«\/Tregan\/Gjinar\/Zavalin\Ã\«\,\ Elbasan",355586 => "Gjergjan\/Pap\Ã\«r\/Shal\Ã\«s\,\ Elbasan",355587 => "Gostime\/Klos\/Mollas\,\ Elbasan",355588 => "Rras\Ã\«\/Fierz\Ã\«\/Kajan\/Grekan\,\ Elbasan",355589 => "Karin\Ã\«\/Gjocaj\/Shez\Ã\«\,\ Peqin",355591 => "P\Ã\«rrenjas\,\ Librazhd",355592 => "Qend\Ã\«r\,\ Librazhd",355593 => "Lunik\/Orenj\Ã\«\/Stebleve\,\ Librazhd",355594 => "Hotolisht\/Polis\/Stravaj\,\ Librazhd",355595 => "Quk\Ã\«s\/Rajc\Ã\«\,\ Librazhd",355596 => "Pishaj\/Sult\/Tunj\Ã\«\/Kushov\Ã\«\/Sk\Ã\«nderbegas\,\ Gramsh",355597 => "Kodovjat\/Poro\Ã\§an\/Kukur\/Lenie\,\ Gramsh",355811 => "Bilisht\,\ Devoll",355812 => "Ersek\Ã\«\,\ Kolonj\Ã\«",355813 => "P\Ã\«rmet",355814 => "Tepelen\Ã\«",355815 => "Delvin\Ã\«",35582 => "Kor\Ã\§\Ã\«",35583 => "Pogradec",35584 => "Gjirokast\Ã\«r",35585 => "Sarand\Ã\«",355860 => "Trebinj\Ã\«\/Proptisht\/Vel\Ã\§an\,\ Pogradec",355861 => "Maliq\,\ Kor\Ã\§\Ã\«",355862 => "Qend\Ã\«r\,\ Kor\Ã\§\Ã\«",355863 => "Drenov\Ã\«\/Mollaj\,\ Kor\Ã\§\Ã\«",355864 => "Voskop\/Voskopoj\Ã\«\/Vithkuq\/Lekas\,\ Kor\Ã\§\Ã\«",355865 => "Gor\Ã\«\/Pirg\/Moglic\Ã\«\,\ Kor\Ã\§\Ã\«",355866 => "Libonik\/Vreshtaz\,\ Kor\Ã\§\Ã\«",355867 => "Pojan\/Liqenas\,\ Kor\Ã\§\Ã\«",355868 => "Bu\Ã\§imas\/Udenisht\,\ Pogradec",355869 => "\Ã\‡\Ã\«rav\Ã\«\/Dardhas\,\ Pogradec",355871 => "Leskovik\/Barmash\/Novosel\Ã\«\,\ Kolonj\Ã\«",355872 => "Qend\Ã\«r\ Ersek\Ã\«\/Mollas\/\Ã\‡lirim\,\ Kolonj\Ã\«",355873 => "Qend\Ã\«r\ Bilisht\/Prog\Ã\«r\,\ Devoll",355874 => "Ho\Ã\§isht\/Miras\,\ Devoll",355875 => "K\Ã\«lcyr\Ã\«\,\ P\Ã\«rmet",355876 => "Qend\Ã\«r\/Frash\Ã\«r\/Petran\/\Ã\‡arshov\Ã\«\,\ P\Ã\«rmet",355877 => "Dishnic\Ã\«\/Suk\Ã\«\/Ballaban\,\ P\Ã\«rmet",355881 => "Libohov\Ã\«\/Qend\Ã\«r\,\ Gjirokast\Ã\«r",355882 => "Cepo\/Picar\/Lazarat\/Atigon\,\ Gjirokast\Ã\«r",355883 => "Lunxheri\/Odrie\/Zagorie\/Pogon\,\ Gjirokast\Ã\«r",355884 => "Dropull\ i\ Posht\Ã\«m\/Dropull\ i\ Sip\Ã\«rm\,\ Gjirokast\Ã\«r",355885 => "Memaliaj\,\ Tepelen\Ã\«",355886 => "Qend\Ã\«r\/Kurvelesh\/Lop\Ã\«z\,\ Tepelen\Ã\«",355887 => "Qesarat\/Krah\Ã\«s\/Luftinje\/Buz\,\ Tepelen\Ã\«",355891 => "Konispol\/Xare\/Markat\,\ Sarand\Ã\«",355892 => "Aliko\/Lukov\Ã\«\,\ Sarand\Ã\«",355893 => "Ksamil\,\ Sarand\Ã\«",355894 => "Livadhja\/Dhiv\Ã\«r\,\ Sarand\Ã\«",355895 => "Finiq\/Mesopotam\/Vergo\,\ Delvin\Ã\«",);
      foreach my $prefix (map { substr($number, 0, $_) } reverse(1..length($number))) {
        return $map{"355$prefix"} if exists($map{"355$prefix"});
      }
      return undef;
    }
sub new {
  my $class = shift;
  my $number = shift;
  $number =~ s/(^\+355|\D)//g;
  my $self = bless({ number => $number, formatters => $formatters, validators => $validators }, $class);
  return $self if ($self->is_valid());
  $number =~ s/(^0)//g;
  $self = bless({ number => $number, formatters => $formatters, validators => $validators }, $class);
  return $self->is_valid() ? $self : undef;
}

1;
